/*-
 *  Copyright 2022 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.gui.tree;

import de.hft.stuttgart.citydoctor2.datastructure.ReliefObject;
import de.hft.stuttgart.citydoctor2.gui.CheckStatus;
import de.hft.stuttgart.citydoctor2.gui.Renderer;

public class ReliefNode extends Renderable {
	
	private final ReliefObject relief;

	public ReliefNode(ReliefObject relief) {
		this.relief = relief;
	}


	@Override
	public void refreshTextColor() {
		if (!relief.isValidated()) {
			setStatus(CheckStatus.NOT_CHECKED);
		} else if (relief.containsAnyError()) {
			setStatus(CheckStatus.ERROR);
		} else {
			setStatus(CheckStatus.OK);
		}		
	}

	@Override
	public String getText() {
		return "[ReliefFeature] " + relief.getGmlId().getGmlString();
	}

	@Override
	public void visit(Renderer renderer) {
		renderer.render(relief);
	}

}
